History
========

0.0.6 (2016-08-05)
------------------

Fix for checkbox rendering and New error class for Non field errors in Foundation 6 

0.0.5 (2016-07-12)
---------------------

* First release on PyPI.
